@@ -10,7 +10,8 @@ use Module::Load         qw/load/;
 use Params::Validate     qw/validate SCALAR ARRAYREF CODEREF UNDEF BOOLEAN
                                      OBJECT HASHREF/;
 use mro 'c3';
-use namespace::autoclean;
+
+use namespace::clean;
 
 use DBIx::DataModel;
 {no strict 'refs'; *CARP_NOT = \@DBIx::DataModel::CARP_NOT;}
